==> mergerfs_2.31.0.orig.tar.gz: mergerfs-2.31.0/src/enum.hpp <==
/*
  ISC License

  Copyright (c) 2019, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "tofrom_string.hpp"

#include <string>

template<typename E>
class Enum : public ToFromString
{
public:
  typedef E ENUM;

public:
  Enum<ENUM>()
  {
  }

  Enum<ENUM>(const ENUM data_)
    : _data(data_)
  {
  }

public:
  Enum<ENUM>&
  operator=(const ENUM data_)
  {
    _data = data_;
    return *this;
  }

  Enum<ENUM>&
  operator=(const std::string &s_)
  {
    from_string(s_);
    return *this;
  }

public:
  operator ENUM() const
  {
    return _data;
  }

public:
  bool operator==(const ENUM data_) const
  {
    return (_data == data_);
  }

public:
  std::string to_string() const;
  int from_string(const std::string &);

public:
  int to_int() const
  {
    return (int)_data;
  }

private:
  ENUM _data;
};

==> mergerfs_2.40.2.orig.tar.gz: mergerfs-2.40.2/src/enum.hpp <==
/*
  ISC License

  Copyright (c) 2019, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "tofrom_string.hpp"

#include <string>


template<typename E>
class Enum : public ToFromString
{
public:
  typedef E ENUM;

public:
  Enum<ENUM>()
  {
  }

  Enum<ENUM>(const ENUM data_)
    : _data(data_)
  {
  }

public:
  Enum<ENUM>&
  operator=(const ENUM data_)
  {
    _data = data_;
    return *this;
  }

  Enum<ENUM>&
  operator=(const std::string &s_)
  {
    from_string(s_);
    return *this;
  }

public:
  operator ENUM() const
  {
    return _data;
  }

public:
  bool operator==(const ENUM data_) const
  {
    return (_data == data_);
  }

public:
  std::string to_string() const final;
  int from_string(const std::string &) final;

public:
  int to_int() const
  {
    return (int)_data;
  }

private:
  ENUM _data;
};
